<?php
/*
Plugin Name:  WP SIMILE Timeline
Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
Description: Integrates the <a href="http://simile.mit.edu/timeline/">SIMILE Timeline</a> with WordPress and provides an option interface for the various timeline settings. With this plugin you can display posts from a specific category in the Timeline Widget. Simply include the <strong>[similetimeline]</strong> shortcode in your page or post and specify the category on the <a href="options-general.php?page=wp-simile-timeline/options/options-timeline.php">admin page</a>.
Author: Tim Isenheim
Author URI: http://www.freshlabs.de/journal
Version: 0.4.1
*/

/*
	SIMILE Timeline for WordPress
    Copyright (C) 2006 Tim Isenheim

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

include('options/timeline-db.php');	// wp-database functions
include('options/options-timeline.php');  // option page

$stl_use_timeline = false;			// initially no timeline is used

@define('STL_TIMELINE_PLUGIN_DATESTRING', '20081020');
@define('STL_TIMELINE_PLUGIN_VERSION', '0.4.0');

$currentLocale = get_locale();
if(!empty($currentLocale)) {
	$moFile = dirname(__FILE__) . "/locale/" . $currentLocale . ".mo";
	if(@file_exists($moFile) && is_readable($moFile)) load_textdomain('stl_timeline', $moFile);
}

/* -----------------------------------------------------------------------------
 * Install the plugin with basic parameters and necessary database tables
 * ---------------------------------------------------------------------------*/
function stl_timeline_init_plugin(){
	stl_timeline_eventend_addcolumn();   // add database for end date
	stl_timeline_add_relationship_table();  // add database table for categories
	stl_upgrade();
}

/* -----------------------------------------------------------------------------
 * Setup all the necessary options
 * ---------------------------------------------------------------------------*/
function stl_upgrade(){
	
	if(!get_option('stl_timeline_plugin_version'))
		add_option('stl_timeline_plugin_version', STL_TIMELINE_PLUGIN_VERSION);
	else{
		update_option('stl_timeline_plugin_version', STL_TIMELINE_PLUGIN_VERSION);
	}
	
	if(!get_option('stl_timelinepageids'))
		add_option('stl_timelinepageids', '0');
	if(!get_option('stl_timelinecategories'))
		add_option('stl_timelinecategories', '1');
	if(!get_option('stl_timeline_locale'))
		add_option('stl_timeline_locale', 'en');
	
	// Option for future posts
	if(!get_option('stl_timeline_showfutureposts'))
		add_option('stl_timeline_showfutureposts', '0');
		
	// Theme options - Safety feature: load defaults when option field is set but empty
	$stbo = get_option('stl_timeline_band_options');
	if(empty($stbo)){
		$v = stl_timeline_get_default_options();
		update_option('stl_timeline_band_options', $v);
	}
	elseif(empty($stbo)){
		add_option('stl_timeline_band_options', stl_timeline_get_default_options());
	}
	
	// delete deprecated options from previous releases
	// resolution - deprecated in 0.36
	stl_uninstall_option('stl_timeline_resolution');
	// static category, width+height - deprecated in 0.32a
	stl_uninstall_option('stl_timelinecategory');
	stl_uninstall_option('stl_timelinewidth');
	stl_uninstall_option('stl_timelineheight');
	
	// update possibly new categories
	stl_timeline_update_relationship_table();
}

/* -----------------------------------------------------------------------------
 * stl_simile_timeline
 * manually output the Timeline markup
 * ---------------------------------------------------------------------------*/
function stl_simile_timeline($cats='1', $id='stl-mytimeline'){
	$timeline = '<div id="'.$id.'" class="stl-timeline"></div>';
	echo $timeline;
}

/* -----------------------------------------------------------------------------
 * stl_output_timeline_markup
 * print the necessary timeline markup (called by shortcode API)
 * ---------------------------------------------------------------------------*/
function stl_output_timeline_markup(){
	return '<div id="stl-timeline" class="stl-timeline"></div>';
}

/* -----------------------------------------------------------------------------
 * stl_is_timeline_page
 * loops all page ids given in the timeline options
 * returns true when the current page has a timeline
 * ---------------------------------------------------------------------------*/
function stl_is_timeline_page($stl_currentpageid){
	$stl_istimelinepage = false;
	$stl_timelinepages = get_option('stl_timelinepageids');
	// Set timeline for all pages when the option is 0
	if($stl_timelinepages == 0 || $stl_timelinepages == 'all'){
		$stl_istimelinepage = true;
	}
	else{
		$stl_timelinepagesarray = split(",", $stl_timelinepages);
		foreach($stl_timelinepagesarray as $stl_timelinepageid):
			if($stl_currentpageid == $stl_timelinepageid){
				$stl_istimelinepage = true;
			}
		endforeach;
	}
	return $stl_istimelinepage;
}

/* -----------------------------------------------------------------------------
 * stl_headerJavaScript
 * outputs the JavaScript implementation in the <head> element
 * ONLY when post_id is set in the SIMILE Timeline options
 * ---------------------------------------------------------------------------*/
function stl_headerJavaScriptCSS(){
	global $post, $stl_use_timeline;
	if( stl_is_timeline_page($post->ID) || $stl_use_timeline ):
	echo '<script src="http://simile.mit.edu/timeline/api/timeline-api.js" type="text/javascript"></script>
	<script src="'.get_settings('siteurl').'/wp-content/plugins/wp-simile-timeline/timeline.js.php?v='.STL_TIMELINE_PLUGIN_DATESTRING.'" type="text/javascript"></script>
	<link rel="stylesheet" href="'.get_settings('siteurl').'/wp-content/plugins/wp-simile-timeline/timeline.css" type="text/css" />' . "\n";
	endif;
}

/* -----------------------------------------------------------------------------
     Outputs necessary admin CSS + JavaScript
 * ---------------------------------------------------------------------------*/
function stl_timeline_admin_head(){
	print "
	<link rel=\"stylesheet\" type=\"text/css\" href=\"".get_settings('siteurl')."/wp-content/plugins/wp-simile-timeline/options/timeline-admin.css\" />
	<script type=\"text/javascript\" src=\"".get_settings('siteurl')."/wp-includes/js/colorpicker.js\"></script>
	<script type=\"text/javascript\" src=\"".get_settings('siteurl')."/wp-content/plugins/wp-simile-timeline/options/timeline-admin.js\"></script>
	";
}

/* -----------------------------------------------------------------------------
 * stl_add_options_page
 * adds an admin page under Options > SIMILE Timeline
 * ---------------------------------------------------------------------------*/
function stl_add_options_page(){
	if (function_exists('add_options_page')) {
		add_options_page('Timeline Options', 'SIMILE Timeline', 8, basename(__FILE__), 'stl_display_admin_page');
	}
}

/* -----------------------------------------------------------------------------
 * stl_add_event_enddate_box
 * adds Date-box to define an end date for an event
 * ---------------------------------------------------------------------------*/

function stl_add_event_enddate_box() {
	global $post, $action;
	
	echo '<div id="stl-date-end" class="postbox">';
	echo '<h3>';
	_e('End date', 'stl_timeline');
	echo '</h3>';
	echo '<div class="inside">';
	stl_timeline_touch_time(($action == 'edit'));
	echo '<p>This date will be used as the end date of an event shown in SIMILE Timeline.</p>';
	echo '</div>';
}

/* -----------------------------------------------------------------------------
 * stl_timeline_touch_time
 * output date selection elements
 * ---------------------------------------------------------------------------*/
function stl_timeline_touch_time($edit = 1, $for_post = 1) {
	global $month, $post, $comment;

	if ( $for_post )
		$edit = ( ('draft' == $post->post_status) && (!$post->stl_timeline_event_end || '0000-00-00 00:00:00' == $post->stl_timeline_event_end) ) ? false : true;
 
	echo '<fieldset><legend><input type="checkbox" class="checkbox" name="edit_timeline_end_date" value="1" id="stl_timeline_end_timestamp" /> <label for="stl_timeline_end_timestamp">'.__('Edit timestamp').'</label></legend>';

	$stl_time_adj = time() + (get_settings('gmt_offset') * 3600);
	$post_date = ($for_post) ? $post->stl_timeline_event_end : $comment->comment_date;
	$stl_jj = ($edit) ? mysql2date('d', $post_date) : gmdate('d', $stl_time_adj);
	$stl_mm = ($edit) ? mysql2date('m', $post_date) : gmdate('m', $stl_time_adj);
	$stl_aa = ($edit) ? mysql2date('Y', $post_date) : gmdate('Y', $stl_time_adj);
	$stl_hh = ($edit) ? mysql2date('H', $post_date) : gmdate('H', $stl_time_adj);
	$stl_mn = ($edit) ? mysql2date('i', $post_date) : gmdate('i', $stl_time_adj);
	$stl_ss = ($edit) ? mysql2date('s', $post_date) : gmdate('s', $stl_time_adj);

	echo "<select name=\"stl_mm\">\n";
	for ($i = 1; $i < 13; $i = $i +1) {
		echo "\t\t\t<option value=\"$i\"";
		if ($i == $stl_mm)
			echo " selected='selected'";
		if ($i < 10) {
			$stl_ii = "0".$i;
		} else {
			$stl_ii = "$i";
		}
		echo ">".$month["$stl_ii"]."</option>\n";
	}
?>
</select>
<input type="text" id="stl_jj" name="stl_jj" value="<?php echo $stl_jj; ?>" size="2" maxlength="2" />
<input type="text" id="stl_aa" name="stl_aa" value="<?php echo $stl_aa ?>" size="4" maxlength="5" /> @ 
<input type="text" id="stl_hh" name="stl_hh" value="<?php echo $stl_hh ?>" size="2" maxlength="2" /> : 
<input type="text" id="stl_mn" name="stl_mn" value="<?php echo $stl_mn ?>" size="2" maxlength="2" /> 
<input type="hidden" id="stl_ss" name="stl_ss" value="<?php echo $stl_ss ?>" size="2" maxlength="2" /> 
<?php
	if ( $edit ) {
		_e('Existing timestamp');
		echo ": {$month[$stl_mm]} $stl_jj, $stl_aa @ $stl_hh:$stl_mn";
	}
?>
</fieldset>
<?php
}

/* Admin Menu actions
-----------------------*/

# extra date box
add_action('dbx_post_sidebar', 'stl_add_event_enddate_box');
# save end date on post edit/save/publish
add_action('wp_insert_post', 'stl_timeline_update_eventend_box');
# add options page
add_action('admin_menu', 'stl_add_options_page');
# admin CSS + JS
add_action('admin_head', 'stl_timeline_admin_head');

/* Init options
------------------------*/
# install new database tables & columns
register_activation_hook(__FILE__,'stl_timeline_init_plugin');
# ...for categories
add_action('add_category', 'stl_add_term_to_db');
#add_action('delete_category', 'stl_delete_cat_from_options');
add_action('delete_category', 'stl_delete_term_from_db');

# uninstall plugin
//add_action('deactivate_simile-timeline/timeline.php', 'stl_timeline_eventend_removecolumn');

/* Page filter (finally add the timeline)
---------------------------------------------*/
add_filter('wp_head', 'stl_headerJavaScriptCSS');
add_shortcode('similetimeline', 'stl_output_timeline_markup');

?>